require "spec_helper"

describe MessageExchange::Get do
  subject { described_class.new('http://www.myurl.woo') }

  it "makes a request to a URL" do
    stub_request(:get, "http://www.myurl.woo/").
         with(:headers => {'Accept'=>'application/json'}).
         to_return(:status => 200, :body => "", :headers => {})
    subject.response
  end

  it "passes the parameters that we configure" do
    stub_request(:get, "http://www.myurl.woo/?foo=bar").
      with(:headers => {'Accept'=>'application/json'})

    described_class.new('http://www.myurl.woo', {:foo => 'bar'}).response
  end

  it "returns a ServerErrorResponse when the request times out" do
    Net::HTTP.stub(:new){ raise Timeout::Error }

    expect(subject.response).to be_a MessageExchange::ServerErrorResponse
  end

  it "does not return a parameter string if there are no parameters" do
    expect(subject.parameter_string).to_not include("?")
  end
end
