require "spec_helper"

describe MessageExchange::Response do
  let(:api_response) { double(:api_response) }

  describe "#status" do
    subject { described_class.new(api_response).status }

    before do
      api_response.stub(:code) { "200" }
    end

    it "returns the status code of the response" do
      expect(subject).to eq(200)
    end
  end

  describe "#body" do
    subject { described_class.new(api_response).body }

    before do
      api_response.stub(:body) { "{\"string\": \"Hello World\"}" }
    end

    it "returns the parsed JSON body" do
      expect(subject).to eq({"string" => "Hello World"})
    end
  end

  describe "#success?" do
    subject { described_class.new(api_response).success? }

    (200..206).map(&:to_s).each do |code|
      context "when #{code}" do
        before do
          api_response.stub(:code) { code }
        end

        it { expect(subject).to be_true }
      end
    end

    context "when the status code is not 20x" do
      before do
        api_response.stub(:code) { 301 }
      end

      it "returns a false" do
        expect(subject).to be_false
      end
    end
  end
end
